

set -ex



test -L $PREFIX/lib/libnvrtc.so
test -L $PREFIX/lib/libnvrtc-builtins.so
test -f $PREFIX/lib/pkgconfig/nvrtc*.pc
test -f $PREFIX/targets/sbsa-linux/include/nvrtc.h
test -L $PREFIX/targets/sbsa-linux/lib/libnvrtc.so
test -L $PREFIX/targets/sbsa-linux/lib/libnvrtc-builtins.so
test -f $PREFIX/targets/sbsa-linux/lib/stubs/libnvrtc.so
exit 0
